@@ -53,12 +53,15 @@ Copyright 2009 Yusuke Kawasaki, all rights reserved.
 
 package Unicode::Emoji::Google;
 use Unicode::Emoji::Base;
+use Unicode::Emoji::DoCoMo;
+use Unicode::Emoji::KDDI;
+use Unicode::Emoji::SoftBank;
+use Unicode::Emoji::Google;
 use Any::Moose;
 extends 'Unicode::Emoji::Base::File';
 has list => (is => 'ro', isa => 'ArrayRef', lazy_build => 1);
-has dataxml => (is => 'rw', isa => 'Str', lazy_build => 1);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub _dataxml { 'emoji4unicode.xml'; }
 
@@ -108,12 +111,14 @@ has kddi_emoji     => (is => 'ro', isa => 'Unicode::Emoji::Base::Emoji', lazy_bu
 has softbank_emoji => (is => 'ro', isa => 'Unicode::Emoji::Base::Emoji', lazy_build => 1);
 has google_emoji   => (is => 'ro', isa => 'Unicode::Emoji::Base::Emoji', lazy_build => 1);
 has unicode_emoji  => (is => 'ro', isa => 'Unicode::Emoji::Base::Emoji', lazy_build => 1);
+has kddiweb_emoji  => (is => 'ro', isa => 'Unicode::Emoji::Base::Emoji', lazy_build => 1);
 
 sub _build_docomo_emoji   { $_[0]->docomo   && Unicode::Emoji::DoCoMo::Emoji->new(unicode_hex => $_[0]->docomo) };
 sub _build_kddi_emoji     { $_[0]->kddi     && Unicode::Emoji::KDDI::Emoji->new(unicode_hex => $_[0]->kddi) };
 sub _build_softbank_emoji { $_[0]->softbank && Unicode::Emoji::SoftBank::Emoji->new(unicode_hex => $_[0]->softbank) };
 sub _build_google_emoji   { $_[0]->google   && Unicode::Emoji::Google::Emoji->new(unicode_hex => $_[0]->google) };
 sub _build_unicode_emoji  { $_[0]->unicode  && Unicode::Emoji::Unicode::Emoji->new(unicode_hex => $_[0]->unicode) };
+sub _build_kddiweb_emoji  { $_[0]->kddi     && Unicode::Emoji::KDDIweb::Emoji->fromKDDI($_[0]->kddi_emoji) };
 
 package Unicode::Emoji::Google::Emoji;
 use Any::Moose;
